@@ -101,7 +101,7 @@ class Product(BaseAPI):
             A named tuple containing the response gotten from paystack's server.
         """
 
-        url = self._url(f"/product?perPage=" + str(pagination))
+        url = self._url("/product?perPage=" + str(pagination))
         query_params = [
             ("page", page),
             ("start_date", start_date),
